FixedPointDecoder<T> class final

Fixed-size decoder for fixed-point values.

Constructors

FixedPointDecoder({required int fixedSize, required (T, int) read(Uint8List buffer, int offset)})
Creates a decoder with fixedSize bytes and a read function.
const

Properties

fixedSize int
The encoded size in bytes.
final
hashCode int
The hash code for this object.
no setterinherited
read → (T, int) Function(Uint8List buffer, int offset)
Reads a value and the next offset from a byte buffer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List buffer) → T
Decodes buffer from the beginning.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited