FixedSizeEncoder<T> class final

A fixed-size encoder where every encoded value occupies exactly fixedSize bytes.

Inheritance

Constructors

FixedSizeEncoder({required int fixedSize, required int write(T value, Uint8List bytes, int offset)})
Creates a fixed-size encoder with the given fixedSize and write callback.

Properties

fixedSize int
The fixed number of bytes produced by this encoder.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode(T value) Uint8List
Encode value into a new Uint8List.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(T value, Uint8List bytes, int offset) int
Write the encoded value into bytes starting at offset.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited