Union2Variant0<T0, T1> class final

Variant 0 for Union2.

Inheritance

Constructors

Union2Variant0(T0 value)
Creates a Union2Variant0.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The zero-based variant index.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T0
The typed variant value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited