VariableSizeDecoder<T> class final

A variable-size decoder whose byte consumption depends on the data.

Inheritance

Constructors

VariableSizeDecoder({required (T, int) read(Uint8List bytes, int offset), int? maxSize})
Creates a variable-size decoder.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxSize int?
The maximum possible size of an encoded value in bytes, if known.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List bytes, [int offset = 0]) → T
Decode a value from bytes, optionally starting at offset.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Uint8List bytes, int offset) → (T, int)
Read a value from bytes starting at offset.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited