FixedSizeEncoder<T> class
final
A fixed-size encoder where every encoded value occupies exactly fixedSize bytes.
Constructors
- FixedSizeEncoder({required int fixedSize, required int write(T value, Uint8List bytes, int offset)})
-
Creates a fixed-size encoder with the given
fixedSizeandwritecallback.
Properties
Methods
-
encode(
T value) → Uint8List -
Encode
valueinto a new Uint8List.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
T value, Uint8List bytes, int offset) → int -
Write the encoded
valueintobytesstarting atoffset.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited