PostOffsetScope class
Extended scope for post-offset functions, which also includes the new pre-offset and the original post-offset.
- Inheritance
-
- Object
- PreOffsetScope
- PostOffsetScope
Constructors
Properties
- bytes → Uint8List
-
The entire byte array being encoded or decoded.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- newPreOffset → int
-
The modified offset used to encode or decode.
final
- postOffset → int
-
The original offset returned by the encoder or decoder.
final
- preOffset → int
-
The original offset prior to encode or decode.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wrapBytes → int Function(int offset)
-
Wraps the offset to the byte array length.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited