VariableSizeDecoder<T> class
final
A variable-size decoder whose byte consumption depends on the data.
Constructors
- VariableSizeDecoder({required (T, int) read(Uint8List bytes, int offset), int? maxSize})
- Creates a variable-size decoder.
Properties
Methods
-
decode(
Uint8List bytes, [int offset = 0]) → T -
Decode a value from
bytes, optionally starting atoffset.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
Uint8List bytes, int offset) → (T, int) -
Read a value from
bytesstarting atoffset.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited